#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc
version:              2.18
visibility:           public
id:                   pandoc-2.18-2xzhd62Te1KICKeMSdHLhG
key:                  pandoc-2.18-2xzhd62Te1KICKeMSdHLhG
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another, and a command-line tool that uses
    this library. The formats it can handle include

    - light markup formats (many variants of Markdown,
    reStructuredText, AsciiDoc, Org-mode, Muse, Textile,
    txt2tags)
    - HTML formats (HTML 4 and 5)
    - Ebook formats (EPUB v2 and v3, FB2)
    - Documentation formats (GNU TexInfo, Haddock)
    - Roff formats (man, ms)
    - TeX formats (LaTeX, ConTeXt)
    - XML formats (DocBook 4 and 5, JATS, TEI Simple, OpenDocument)
    - Outline formats (OPML)
    - Bibliography formats (BibTeX, BibLaTeX, CSL JSON, CSL YAML)
    - Word processor formats (Docx, RTF, ODT)
    - Interactive notebook formats (Jupyter notebook ipynb)
    - Page layout formats (InDesign ICML)
    - Wiki markup formats (MediaWiki, DokuWiki, TikiWiki, TWiki,
    Vimwiki, XWiki, ZimWiki, Jira wiki, Creole)
    - Slide show formats (LaTeX Beamer, PowerPoint, Slidy,
    reveal.js, Slideous, S5, DZSlides)
    - Data formats (CSV tables)
    - PDF (via external programs such as pdflatex or wkhtmltopdf)

    Pandoc can convert mathematical content in documents
    between TeX, MathML, Word equations, roff eqn, and plain text.
    It includes a powerful system for automatic citations
    and bibliographies, and it can be customized extensively
    using templates, filters, and custom readers and writers
    written in Lua.

category:             Text
abi:                  e25122511b3e2d49d3b150816cee3b4e
exposed:              True
exposed-modules:
    Text.Pandoc Text.Pandoc.App Text.Pandoc.Asciify
    Text.Pandoc.Citeproc Text.Pandoc.Class Text.Pandoc.Emoji
    Text.Pandoc.Error Text.Pandoc.Extensions Text.Pandoc.Filter
    Text.Pandoc.Highlighting Text.Pandoc.ImageSize Text.Pandoc.Logging
    Text.Pandoc.Lua Text.Pandoc.MIME Text.Pandoc.MediaBag
    Text.Pandoc.Options Text.Pandoc.PDF Text.Pandoc.Parsing
    Text.Pandoc.Process Text.Pandoc.Readers Text.Pandoc.Readers.BibTeX
    Text.Pandoc.Readers.CSV Text.Pandoc.Readers.CommonMark
    Text.Pandoc.Readers.Creole Text.Pandoc.Readers.CslJson
    Text.Pandoc.Readers.Custom Text.Pandoc.Readers.DocBook
    Text.Pandoc.Readers.Docx Text.Pandoc.Readers.DokuWiki
    Text.Pandoc.Readers.EPUB Text.Pandoc.Readers.EndNote
    Text.Pandoc.Readers.FB2 Text.Pandoc.Readers.HTML
    Text.Pandoc.Readers.Haddock Text.Pandoc.Readers.Ipynb
    Text.Pandoc.Readers.JATS Text.Pandoc.Readers.Jira
    Text.Pandoc.Readers.LaTeX Text.Pandoc.Readers.Man
    Text.Pandoc.Readers.Markdown Text.Pandoc.Readers.MediaWiki
    Text.Pandoc.Readers.Muse Text.Pandoc.Readers.Native
    Text.Pandoc.Readers.OPML Text.Pandoc.Readers.Odt
    Text.Pandoc.Readers.Org Text.Pandoc.Readers.RIS
    Text.Pandoc.Readers.RST Text.Pandoc.Readers.RTF
    Text.Pandoc.Readers.TWiki Text.Pandoc.Readers.Textile
    Text.Pandoc.Readers.TikiWiki Text.Pandoc.Readers.Txt2Tags
    Text.Pandoc.Readers.Vimwiki Text.Pandoc.SelfContained
    Text.Pandoc.Shared Text.Pandoc.Sources Text.Pandoc.Templates
    Text.Pandoc.UTF8 Text.Pandoc.Writers
    Text.Pandoc.Writers.AnnotatedTable Text.Pandoc.Writers.AsciiDoc
    Text.Pandoc.Writers.BibTeX Text.Pandoc.Writers.CommonMark
    Text.Pandoc.Writers.ConTeXt Text.Pandoc.Writers.CslJson
    Text.Pandoc.Writers.Custom Text.Pandoc.Writers.Docbook
    Text.Pandoc.Writers.Docx Text.Pandoc.Writers.DokuWiki
    Text.Pandoc.Writers.EPUB Text.Pandoc.Writers.FB2
    Text.Pandoc.Writers.HTML Text.Pandoc.Writers.Haddock
    Text.Pandoc.Writers.ICML Text.Pandoc.Writers.Ipynb
    Text.Pandoc.Writers.JATS Text.Pandoc.Writers.Jira
    Text.Pandoc.Writers.LaTeX Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.Math
    Text.Pandoc.Writers.MediaWiki Text.Pandoc.Writers.Ms
    Text.Pandoc.Writers.Muse Text.Pandoc.Writers.Native
    Text.Pandoc.Writers.ODT Text.Pandoc.Writers.OOXML
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.Powerpoint
    Text.Pandoc.Writers.RST Text.Pandoc.Writers.RTF
    Text.Pandoc.Writers.Shared Text.Pandoc.Writers.TEI
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.XWiki Text.Pandoc.Writers.ZimWiki
    Text.Pandoc.XML

hidden-modules:
    Text.Pandoc.App.CommandLineOptions Text.Pandoc.App.FormatHeuristics
    Text.Pandoc.App.Opt Text.Pandoc.App.OutputSettings
    Text.Pandoc.Class.CommonState Text.Pandoc.Class.IO
    Text.Pandoc.Class.PandocMonad Text.Pandoc.Class.PandocIO
    Text.Pandoc.Class.PandocPure Text.Pandoc.Class.Sandbox
    Text.Pandoc.Filter.Environment Text.Pandoc.Filter.JSON
    Text.Pandoc.Filter.Lua Text.Pandoc.Filter.Path
    Text.Pandoc.Parsing.Capabilities Text.Pandoc.Parsing.Citations
    Text.Pandoc.Parsing.General Text.Pandoc.Parsing.GridTable
    Text.Pandoc.Parsing.Lists Text.Pandoc.Parsing.Math
    Text.Pandoc.Parsing.Smart Text.Pandoc.Parsing.State
    Text.Pandoc.Parsing.Types Text.Pandoc.Readers.Docx.Lists
    Text.Pandoc.Readers.Docx.Combine Text.Pandoc.Readers.Docx.Parse
    Text.Pandoc.Readers.Docx.Parse.Styles Text.Pandoc.Readers.Docx.Util
    Text.Pandoc.Readers.Docx.Fields Text.Pandoc.Readers.HTML.Parsing
    Text.Pandoc.Readers.HTML.Table
    Text.Pandoc.Readers.HTML.TagCategories
    Text.Pandoc.Readers.HTML.Types Text.Pandoc.Readers.LaTeX.Inline
    Text.Pandoc.Readers.LaTeX.Citation Text.Pandoc.Readers.LaTeX.Lang
    Text.Pandoc.Readers.LaTeX.Macro Text.Pandoc.Readers.LaTeX.Math
    Text.Pandoc.Readers.LaTeX.Parsing Text.Pandoc.Readers.LaTeX.SIunitx
    Text.Pandoc.Readers.LaTeX.Table Text.Pandoc.Readers.LaTeX.Types
    Text.Pandoc.Readers.Odt.Base Text.Pandoc.Readers.Odt.Namespaces
    Text.Pandoc.Readers.Odt.StyleReader
    Text.Pandoc.Readers.Odt.ContentReader
    Text.Pandoc.Readers.Odt.Generic.Fallible
    Text.Pandoc.Readers.Odt.Generic.SetMap
    Text.Pandoc.Readers.Odt.Generic.Utils
    Text.Pandoc.Readers.Odt.Generic.Namespaces
    Text.Pandoc.Readers.Odt.Generic.XMLConverter
    Text.Pandoc.Readers.Odt.Arrows.State
    Text.Pandoc.Readers.Odt.Arrows.Utils
    Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
    Text.Pandoc.Readers.Org.DocumentTree
    Text.Pandoc.Readers.Org.ExportSettings
    Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
    Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
    Text.Pandoc.Readers.Org.Shared Text.Pandoc.Readers.Metadata
    Text.Pandoc.Readers.Roff Text.Pandoc.Writers.Docx.StyleMap
    Text.Pandoc.Writers.Docx.Table Text.Pandoc.Writers.Docx.Types
    Text.Pandoc.Writers.GridTable Text.Pandoc.Writers.JATS.References
    Text.Pandoc.Writers.JATS.Table Text.Pandoc.Writers.JATS.Types
    Text.Pandoc.Writers.LaTeX.Caption Text.Pandoc.Writers.LaTeX.Notes
    Text.Pandoc.Writers.LaTeX.Table Text.Pandoc.Writers.LaTeX.Lang
    Text.Pandoc.Writers.LaTeX.Types Text.Pandoc.Writers.LaTeX.Citation
    Text.Pandoc.Writers.LaTeX.Util Text.Pandoc.Writers.Markdown.Table
    Text.Pandoc.Writers.Markdown.Types
    Text.Pandoc.Writers.Markdown.Inline Text.Pandoc.Writers.Roff
    Text.Pandoc.Writers.Blaze
    Text.Pandoc.Writers.Powerpoint.Presentation
    Text.Pandoc.Writers.Powerpoint.Output
    Text.Pandoc.Lua.ErrorConversion Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Types Text.Pandoc.Lua.Module.Utils
    Text.Pandoc.Lua.Orphans Text.Pandoc.Lua.Packages
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.XML.Light Text.Pandoc.XML.Light.Types
    Text.Pandoc.XML.Light.Proc Text.Pandoc.XML.Light.Output
    Text.Pandoc.Network.HTTP Text.Pandoc.CSS Text.Pandoc.CSV
    Text.Pandoc.RoffChar Text.Pandoc.UUID Text.Pandoc.Translations
    Text.Pandoc.Slides Text.Pandoc.Image Text.Pandoc.Citeproc.BibTeX
    Text.Pandoc.Citeproc.CslJson Text.Pandoc.Citeproc.Data
    Text.Pandoc.Citeproc.Locator Text.Pandoc.Citeproc.MetaValue
    Text.Pandoc.Citeproc.Util Paths_pandoc

import-dirs:          /usr/lib/ghc-9.0.2/site-local/pandoc-2.18
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pandoc-2.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc
hs-libraries:         HSpandoc-2.18-2xzhd62Te1KICKeMSdHLhG
depends:
    Glob-0.10.2-HUajPMbLim43ayGE4Sz2N7
    JuicyPixels-3.3.7-Fn7rJtLCEUmBDFby1Qj1gt
    SHA-1.6.4.4-1UNVNO3JXJdDGqRoMkntZx
    aeson-1.5.6.0-IFKx7d1uRXb5sUuKtSGu5t
    aeson-pretty-0.8.9-COSnpIyuMcREGNVnXc2eRQ array-0.5.4.0
    attoparsec-0.14.4-Kojlk2njjLp4GDvYR5lc9z base-4.15.1.0
    base64-bytestring-1.2.1.0-BJuXRBAdLOsHfwJFsLaaPA binary-0.8.8.0
    blaze-html-0.9.1.2-DxdYpnkq6XjDhFxj92gki9
    blaze-markup-0.8.2.8-1mxmhfjSNy89m3pDytthwl bytestring-0.10.12.1
    case-insensitive-1.2.1.0-AxU2XVuOes5CFI4MXNB5c7
    citeproc-0.7-KFEuIOMSo5113Y4uEQ3GTK
    commonmark-0.2.2-9oeuIHYHqB08gnj0Trsjcy
    commonmark-extensions-0.2.3.1-rUxsH6SNeyISUkXY1E5OV
    commonmark-pandoc-0.2.1.2-ErIOBIxLtooFZkF36abZIO
    connection-0.3.1-bFRmuSDkZd3hlGj3zaJy6 containers-0.6.4.1
    data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW deepseq-1.4.5.0
    directory-1.3.6.2 doclayout-0.4-GU1GhjeufnvHFbPK5m5JsX
    doctemplates-0.10.0.1-GgSFRPXaryA2Mk7xKQhvvY
    emojis-0.1.2-ApHRadKnIlX53pfVKoXU2r exceptions-0.10.4
    file-embed-0.0.15.0-FF5xUPWKaB3GI64c6hgPnn filepath-1.4.2.1
    haddock-library-1.10.0-9oiUyLHCVIwBsoaFAFHBuE
    hslua-2.2.0-6LT6Ge1IIKCCQeAANnIiGK
    hslua-module-doclayout-1.0.4-AKVm3DzCsB13GT0QnO5clu
    hslua-module-path-1.0.1-DHAtMz2I1DgJTQks7uLj5G
    hslua-module-system-1.0.1-9eIKyLGuRi67zElSUMWrJR
    hslua-module-text-1.0.1-II0yinWhZmABUDDRTThSJY
    hslua-module-version-1.0.1-1FCuiHrlZ1PbDYGQWkrdw
    http-client-0.7.11-1oXcmJasziVB1JF5sWxqvH
    http-client-tls-0.3.6.1-BIpXawm6tqzCfZmZDCOazu
    http-types-0.12.3-HvT6bJuxvKDh0p4h5wana
    ipynb-0.2-ISE54thf3qYJLtJX1rasi5
    jira-wiki-markup-1.4.0-1i8bAD31LvL2Tlk20AV6YJ
    lpeg-1.0.2-L1e3LTRnJL8FqhHPGLI7nG mtl-2.2.2
    network-3.1.2.7-BfLNNWIREyL84biQKbgmoR
    network-uri-2.6.4.1-63b1khi2w6s6RXlPi9KnXX
    pandoc-lua-marshal-0.1.5.1-7iTkqRfmyvOamGV4ATgN9
    pandoc-types-1.22.2-6yDHfIXZIYvI95o1XRD6jC parsec-3.1.14.0
    pretty-1.1.3.6 pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    process-1.6.13.2 random-1.2.1.1-CPzrEs7ZPWa61oDCTMsEJ2
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    scientific-0.3.7.0-LNws5OCUL8XATryCeYCuvB
    skylighting-0.12.3.1-B5ZO5A0AXjbAAiXEY1H6TC
    skylighting-core-0.12.3.1-6qXBF69Y7KJIKtQQggc85F
    split-0.2.3.4-5g0dljekHtuCs891rRrlnl
    syb-0.7.2.1-JCnPFSOVYTDHyylPg1ArvR
    tagsoup-0.14.8-716EBPOHpo6J7MqUxgfhD6
    temporary-1.3-C2gh2yFsbWf4gLeva6iXbE
    texmath-0.12.5.1-7WMQns8aerx52zWXyWz8fF text-1.2.5.0
    text-conversions-0.3.1.1-IbpGbsr8wmy3M0OaJshKOU time-1.9.3
    unicode-collation-0.1.3.2-HchSMQ5tdNG2VegxfDBXIj
    unicode-transforms-0.4.0.1-419U23UbCYFHFkALRXC4E9 unix-2.7.2.2
    xml-1.3.14-6hlhhPBptprHwK7nsE7OzM
    xml-conduit-1.9.1.1-DiGzYrSxajGC3Gf7c7YEeO
    xml-types-0.3.8-5QCBKSWiifmEtQB2jlqHYu
    yaml-0.11.8.0-IuQz64kUsp3LJBSG15MVLc
    zip-archive-0.4.2.1-1vEFukLcYx8BRENzZyq3gD
    zlib-0.6.3.0-JEDdY1a1MCvHKdNjJAVjbt

haddock-interfaces:   /usr/share/doc/pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

